import {Invoke} from "../wailsjs/go/controller/App";

export interface Resp<T> {
    status: number;
    msg: string;
    err: string;
    data: T;
}

// 类型保护函数
function isResp<T>(obj: any): obj is Resp<T> {
    return (
        typeof obj === 'object' &&
        obj !== null &&
        typeof obj.status === 'number' &&
        (typeof obj.msg === 'string' || typeof obj.msg === null) &&
        (typeof obj.err === 'string' || typeof obj.err === null)
    );
}

const invoke = async <T>(path: string, req: any): Promise<Resp<T>> => {
    const bs = JSON.stringify(req)
    console.log(`[DEBUG] invoke req: path = ${path}, req =`, req)
    const res = await Invoke(path, bs)
    console.log(`[DEBUG] invoke res: path = ${path}, res =`, res)
    try {
        const parsed = JSON.parse(res);
        if (isResp<T>(parsed)) {
            return parsed;
        } else {
            console.error('[ERROR] invoke: resp not valid =', res)
            throw new Error('Parsed response does not match Resp<T> structure');
        }
    } catch (error) {
        console.error(`[ERROR] invoke: resp parse err, err = ${error}, res =`, res);
        throw new Error('Invalid response format');
    }
}

export const Dial = invoke;